==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/uk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Сховище тимчасове недоступне",
    "Storage invalid" : "Неправильне сховище",
    "Unknown error" : "Невідома помилка",
    "All files" : "Усі файли",
    "Saved" : "Збережено",
    "File could not be found" : "Файл не знайдено",
    "Home" : "Домашня адреса",
    "Close" : "Закрити",
    "Favorites" : "Улюблені",
    "Could not create folder \"{dir}\"" : "Неможливо створити теку \"{dir}\"",
    "Upload cancelled." : "Вивантаження скасовано.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо вивантажити {filename}, оскільки це каталог або файл має розмір 0 байт.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви вивантажуєте {size1}, а залишилося лише {size2}",
    "Not enough free space" : "Недостатньо вільного місця",
    "Uploading..." : "Вивантаження...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Виконується вивантаження файлу. Закриття цієї сторінки приведе до скасування вивантаження.",
    "Actions" : "Дії",
    "Download" : "Завантажити",
    "Rename" : "Перейменувати",
    "Delete" : "Видалити",
    "Disconnect storage" : "Від’єднати сховище",
    "Unshare" : "Закрити спільний доступ",
    "Files" : "Файли",
    "Details" : "Деталі",
    "Select" : "Оберіть",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "Invalid path" : "Невірний шлях",
    "This operation is forbidden" : "Ця операція заборонена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорія недоступна, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "Could not move \"{file}\", target exists" : "Не вдалося перемістити \"{file}\", такий файл вже існує",
    "Could not move \"{file}\"" : "Не вдалося перемістити \"{file}\"",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n "],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n "],
    "{dirs} and {files}" : "{dirs} і {files}",
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів"],
    "New" : "Створити",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані !",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше сховище майже повне ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'"],
    "Favorited" : "Улюблений",
    "Favorite" : "Улюблений",
    "Folder" : "Тека",
    "New folder" : "Нова тека",
    "Upload" : "Вивантажити",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "A new file or folder has been <strong>created</strong>" : "Новий файл або теку було <strong>створено</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл або теку було <strong> змінено </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Обмежити повідомлення про створення та зміни в ваших <strong>улюблених файлах</strong>\n<em>(Тількі потік)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Файл або теку було <strong> видалено </strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
    "You created %1$s" : "Вами створено %1$s",
    "%2$s created %1$s" : "%2$s створено %1$s",
    "%1$s was created in a public folder" : "%1$s створено у публічній теці",
    "You changed %1$s" : "Вами змінено %1$s",
    "%2$s changed %1$s" : "%2$s змінено %1$s",
    "You deleted %1$s" : "Вами видалено %1$s",
    "%2$s deleted %1$s" : "%2$s видалено %1$s",
    "You restored %1$s" : "Вами відновлено %1$s",
    "%2$s restored %1$s" : "%2$s відновлено %1$s",
    "Upload (max. %s)" : "Вивантаження (макс. %s)",
    "File handling" : "Робота з файлами",
    "Maximum upload size" : "Максимальний розмір вивантажень",
    "max. possible: " : "макс. можливе:",
    "Save" : "Зберегти",
    "Settings" : "Налаштування",
    "WebDAV" : "WebDAV",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
    "No entries found in this folder" : "В цій теці нічого немає",
    "Select all" : "Вибрати всі",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли,що ви намагаєтесь вивантажити перевищують максимальний дозволений розмір файлів на цьому сервері.",
    "No favorites" : "Немає улюблених",
    "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут",
    "Text file" : "Текстовий файл",
    "New text file.txt" : "Новий текстовий файл file.txt",
    "Unknown user" : "Невідомий користувач"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/uk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Сховище тимчасове недоступне",
    "Storage invalid" : "Неправильне сховище",
    "Unknown error" : "Невідома помилка",
    "All files" : "Усі файли",
    "File could not be found" : "Файл не знайдено",
    "Home" : "Домашня адреса",
    "Close" : "Закрити",
    "Favorites" : "Улюблені",
    "Could not create folder \"{dir}\"" : "Неможливо створити теку \"{dir}\"",
    "Upload cancelled." : "Вивантаження скасовано.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо вивантажити {filename}, оскільки це каталог або файл має розмір 0 байт.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви вивантажуєте {size1}, а залишилося лише {size2}",
    "Not enough free space" : "Недостатньо вільного місця",
    "Uploading..." : "Вивантаження...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Виконується вивантаження файлу. Закриття цієї сторінки приведе до скасування вивантаження.",
    "Actions" : "Дії",
    "Download" : "Завантажити",
    "Rename" : "Перейменувати",
    "Delete" : "Видалити",
    "Disconnect storage" : "Від’єднати сховище",
    "Unshare" : "Закрити спільний доступ",
    "Files" : "Файли",
    "Details" : "Деталі",
    "Select" : "Оберіть",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "Invalid path" : "Невірний шлях",
    "This operation is forbidden" : "Ця операція заборонена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорія недоступна, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "group" : "група",
    "Remote share" : "Віддалена загальна тека",
    "Could not move \"{file}\", target exists" : "Не вдалося перемістити \"{file}\", такий файл вже існує",
    "Could not move \"{file}\"" : "Не вдалося перемістити \"{file}\"",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n ","теки : %n "],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n ","файли : %n "],
    "{dirs} and {files}" : "{dirs} і {files}",
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів","Вивантаження %n файлів"],
    "New" : "Створити",
    "Unknown user" : "Невідомий користувач",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані !",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше сховище майже повне ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'"],
    "Favorited" : "Улюблений",
    "Favorite" : "Улюблений",
    "Folder" : "Тека",
    "New folder" : "Нова тека",
    "Upload" : "Вивантажити",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "A new file or folder has been <strong>created</strong>" : "Новий файл або теку було <strong>створено</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл або теку було <strong> змінено </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Обмежити повідомлення про створення та зміни в ваших <strong>улюблених файлах</strong>\n<em>(Тількі потік)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Файл або теку було <strong> видалено </strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
    "You created %1$s" : "Вами створено %1$s",
    "%2$s created %1$s" : "%2$s створено %1$s",
    "%1$s was created in a public folder" : "%1$s створено у публічній теці",
    "You changed %1$s" : "Вами змінено %1$s",
    "%2$s changed %1$s" : "%2$s змінено %1$s",
    "You deleted %1$s" : "Вами видалено %1$s",
    "%2$s deleted %1$s" : "%2$s видалено %1$s",
    "You restored %1$s" : "Вами відновлено %1$s",
    "%2$s restored %1$s" : "%2$s відновлено %1$s",
    "Upload (max. %s)" : "Вивантаження (макс. %s)",
    "Settings" : "Налаштування",
    "WebDAV" : "WebDAV",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
    "No entries found in this folder" : "В цій теці нічого немає",
    "Select all" : "Вибрати всі",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли,що ви намагаєтесь вивантажити перевищують максимальний дозволений розмір файлів на цьому сервері.",
    "No favorites" : "Немає улюблених",
    "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут",
    "Text file" : "Текстовий файл",
    "New text file.txt" : "Новий текстовий файл file.txt"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
